==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/PopupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnClosedEventArgsDescriptionMetadata } from "./OnClosedEventArgsDescriptionMetadata";
import { OnPopupEventArgsDescriptionMetadata } from "./OnPopupEventArgsDescriptionMetadata";
import { PopupDescription } from "./PopupDescription";
/**
 * @hidden
 */
var PopupDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PopupDescriptionMetadata, _super);
    function PopupDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PopupDescriptionMetadata.b = function (a) {
        if (PopupDescriptionMetadata.a == null) {
            PopupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PopupDescriptionMetadata.c(PopupDescriptionMetadata.a);
        }
        if (a.j(PopupDescriptionMetadata.a)) {
            return;
        }
        a.y(PopupDescriptionMetadata.a);
        OnClosedEventArgsDescriptionMetadata.d(a);
        OnPopupEventArgsDescriptionMetadata.d(a);
    };
    PopupDescriptionMetadata.c = function (a) {
        a.item("AnimationDuration", "Number:int");
        a.item("AnimationEnabled", "Boolean");
        a.item("Elevation", "Number:int");
        a.item("ActualElevation", "Number:int");
        a.item("ActualUmbraShadowColor", "Brush");
        a.item("ActualPenumbraShadowColor", "Brush");
        a.item("ActualAmbientShadowColor", "Brush");
        a.item("Background", "Brush");
        a.item("OnClosedRef", "EventRef::onClosed");
        a.item("OnPopupRef", "EventRef::onPopup");
    };
    PopupDescriptionMetadata.d = function (a) {
        PopupDescriptionMetadata.b(a);
        a.aa("Popup", function () { return new PopupDescription(); });
        a.z("Popup", PopupDescriptionMetadata.a);
    };
    PopupDescriptionMetadata.$t = markType(PopupDescriptionMetadata, 'PopupDescriptionMetadata');
    PopupDescriptionMetadata.a = null;
    return PopupDescriptionMetadata;
}(Base));
export { PopupDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/PopupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnClosedEventArgsDescriptionMetadata } from "./OnClosedEventArgsDescriptionMetadata";
import { OnPopupEventArgsDescriptionMetadata } from "./OnPopupEventArgsDescriptionMetadata";
import { PopupDescription } from "./PopupDescription";
/**
 * @hidden
 */
var PopupDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PopupDescriptionMetadata, _super);
    function PopupDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PopupDescriptionMetadata.b = function (a) {
        if (PopupDescriptionMetadata.a == null) {
            PopupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PopupDescriptionMetadata.c(PopupDescriptionMetadata.a);
        }
        if (a.k(PopupDescriptionMetadata.a)) {
            return;
        }
        a.aa(PopupDescriptionMetadata.a);
        OnClosedEventArgsDescriptionMetadata.d(a);
        OnPopupEventArgsDescriptionMetadata.d(a);
    };
    PopupDescriptionMetadata.c = function (a) {
        a.item("AnimationDuration", "Number:int");
        a.item("AnimationEnabled", "Boolean");
        a.item("Elevation", "Number:int");
        a.item("ActualElevation", "Number:int");
        a.item("ActualUmbraShadowColor", "Brush");
        a.item("ActualPenumbraShadowColor", "Brush");
        a.item("ActualAmbientShadowColor", "Brush");
        a.item("Background", "Brush");
        a.item("OnClosedRef", "EventRef::onClosed");
        a.item("OnPopupRef", "EventRef::onPopup");
    };
    PopupDescriptionMetadata.d = function (a) {
        PopupDescriptionMetadata.b(a);
        a.ac("Popup", function () { return new PopupDescription(); });
        a.ab("Popup", PopupDescriptionMetadata.a);
    };
    PopupDescriptionMetadata.$t = markType(PopupDescriptionMetadata, 'PopupDescriptionMetadata');
    PopupDescriptionMetadata.a = null;
    return PopupDescriptionMetadata;
}(Base));
export { PopupDescriptionMetadata };
